Struct language_e2e_tests::account::AccountData[][src]

pub struct AccountData { /* fields omitted */ }
Represents an account along with initial state about it.

AccountData captures the initial state needed to create accounts for tests.

Implementations

Creates a new AccountData with a new account.

This constructor is non-deterministic and should not be used against golden file.

Creates a new AccountData with a new account.

Most tests will want to use this constructor.

Creates a new AccountData with a new account, with XDX balance.

Most tests will want to use this constructor.

Creates a new AccountData with the provided account.

Creates a new AccountData with the provided account.

Creates a new AccountData with custom parameters.

Adds the balance held by this account to the one represented as balance_currency_code

Changes the keys for this account to the provided ones.

Returns the (Move value) layout of the DiemAccount::DiemAccount struct

Returns the account role specifier

Creates and returns the top-level resources to be published under the account

Returns the AccessPath that describes the Account resource instance.

Use this to retrieve or publish the Account blob.

Returns the AccessPath that describes the Account balance resource instance.

Use this to retrieve or publish the Account blob.

Creates a writeset that contains the account data and can be patched to the storage directly.

Returns the address of the account. This is a hash of the public key the account was created with.

The address does not change if the account’s keys are rotated.

Returns the underlying Account instance.

Converts this data into an Account instance.

Returns the initial balance.

Returns the initial sequence number.

Returns the unique key for this sent events stream.

Returns the initial sent events count.

Returns the unique key for this received events stream.

Returns the initial received events count.

Returns a [Strategy] that creates AccountData instances.