Struct language_e2e_tests::account::Account [−][src]
pub struct Account {
pub privkey: Ed25519PrivateKey,
pub pubkey: Ed25519PublicKey,
// some fields omitted
}Expand description
Details about a Diem account.
Tests will typically create a set of Account instances to run transactions on. This type
encodes the logic to operate on and verify operations on any Diem account.
Fields
privkey: Ed25519PrivateKeyThe current private key for this account.
pubkey: Ed25519PublicKeyThe current public key for this account.
Implementations
Creates a new account in memory.
The account returned by this constructor is a purely logical entity, meaning that it does
not automatically get added to the Diem store. To add an account to the store, use
AccountData instances with
FakeExecutor::add_account_data.
This function returns distinct values upon every call.
Creates a new account in memory given a random seed.
Creates a new account with the given keypair.
Like with Account::new, the account returned by this constructor is a purely logical
entity.
pub fn new_validator(
addr: AccountAddress,
privkey: Ed25519PrivateKey,
pubkey: Ed25519PublicKey
) -> Self
pub fn new_validator(
addr: AccountAddress,
privkey: Ed25519PrivateKey,
pubkey: Ed25519PublicKey
) -> Self
Creates a new account with the given addr and key pair
Like with Account::new, the account returned by this constructor is a purely logical
entity.
Creates a new account in memory representing an account created in the genesis transaction.
The address will be [address], which should be an address for a genesis account and
the account will use [GENESIS_KEYPAIR][struct@GENESIS_KEYPAIR] as its keypair.
Creates a new account representing the diem root account in memory.
The address will be diem_root_address, and
the account will use [GENESIS_KEYPAIR][struct@GENESIS_KEYPAIR] as its keypair.
Creates a new account representing treasury compliance in memory.
The account will use [GENESIS_KEYPAIR][struct@GENESIS_KEYPAIR] as its keypair.
Returns the address of the account. This is a hash of the public key the account was created with.
The address does not change if the account’s keys are rotated.
Returns the AccessPath that describes the Account resource instance.
Use this to retrieve or publish the Account blob.
Returns the AccessPath that describes the Account balance resource instance.
Use this to retrieve or publish the Account balance blob.
Changes the keys for this account to the provided ones.
Computes the authentication key for this account, as stored on the chain.
This is the same as the account’s address if the keys have never been rotated.
Return the first 16 bytes of the account’s auth key