Struct language_e2e_tests::account::AccountData [−][src]
pub struct AccountData { /* fields omitted */ }Expand description
Represents an account along with initial state about it.
AccountData captures the initial state needed to create accounts for tests.
Implementations
Creates a new AccountData with a new account.
This constructor is non-deterministic and should not be used against golden file.
Creates a new AccountData with a new account.
Most tests will want to use this constructor.
Creates a new AccountData with a new account, with XDX balance.
Most tests will want to use this constructor.
pub fn with_account(
account: Account,
balance: u64,
balance_currency_code: Identifier,
sequence_number: u64,
account_specifier: AccountRoleSpecifier
) -> Self
pub fn with_account(
account: Account,
balance: u64,
balance_currency_code: Identifier,
sequence_number: u64,
account_specifier: AccountRoleSpecifier
) -> Self
Creates a new AccountData with the provided account.
pub fn with_keypair(
privkey: Ed25519PrivateKey,
pubkey: Ed25519PublicKey,
balance: u64,
balance_currency_code: Identifier,
sequence_number: u64,
account_specifier: AccountRoleSpecifier
) -> Self
pub fn with_keypair(
privkey: Ed25519PrivateKey,
pubkey: Ed25519PublicKey,
balance: u64,
balance_currency_code: Identifier,
sequence_number: u64,
account_specifier: AccountRoleSpecifier
) -> Self
Creates a new AccountData with the provided account.
pub fn with_account_and_event_counts(
account: Account,
balance: u64,
balance_currency_code: Identifier,
sequence_number: u64,
sent_events_count: u64,
received_events_count: u64,
account_specifier: AccountRoleSpecifier
) -> Self
pub fn with_account_and_event_counts(
account: Account,
balance: u64,
balance_currency_code: Identifier,
sequence_number: u64,
sent_events_count: u64,
received_events_count: u64,
account_specifier: AccountRoleSpecifier
) -> Self
Creates a new AccountData with custom parameters.
Adds the balance held by this account to the one represented as balance_currency_code
Changes the keys for this account to the provided ones.
Returns the (Move value) layout of the DiemAccount::DiemAccount struct
Returns the account role specifier
Creates and returns the top-level resources to be published under the account
Returns the AccessPath that describes the Account resource instance.
Use this to retrieve or publish the Account blob.
Returns the AccessPath that describes the Account balance resource instance.
Use this to retrieve or publish the Account blob.
Creates a writeset that contains the account data and can be patched to the storage directly.
Returns the address of the account. This is a hash of the public key the account was created with.
The address does not change if the account’s keys are rotated.
Converts this data into an Account instance.
Returns the initial sequence number.
Returns the unique key for this sent events stream.
Returns the initial sent events count.
Returns the unique key for this received events stream.
Returns the initial received events count.